@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -115,7 +115,7 @@ class DocumentUnderstandingServiceClient(
 
         return api_endpoint.replace(".googleapis.com", ".mtls.googleapis.com")
 
-    DEFAULT_ENDPOINT = "us-documentai.googleapis.com"
+    DEFAULT_ENDPOINT = "documentai.googleapis.com"
     DEFAULT_MTLS_ENDPOINT = _get_default_mtls_endpoint.__func__(  # type: ignore
         DEFAULT_ENDPOINT
     )
@@ -340,15 +340,14 @@ class DocumentUnderstandingServiceClient(
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def batch_process_documents(
         self,
-        request: document_understanding.BatchProcessDocumentsRequest = None,
+        request: Union[
+            document_understanding.BatchProcessDocumentsRequest, dict
+        ] = None,
         *,
         requests: Sequence[document_understanding.ProcessDocumentRequest] = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -359,7 +358,7 @@ class DocumentUnderstandingServiceClient(
         written to Cloud Storage as JSON in the [Document] format.
 
         Args:
-            request (google.cloud.documentai_v1beta2.types.BatchProcessDocumentsRequest):
+            request (Union[google.cloud.documentai_v1beta2.types.BatchProcessDocumentsRequest, dict]):
                 The request object. Request to batch process documents
                 as an asynchronous operation. The output is written to
                 Cloud Storage as JSON in the [Document] format.
@@ -431,7 +430,7 @@ class DocumentUnderstandingServiceClient(
 
     def process_document(
         self,
-        request: document_understanding.ProcessDocumentRequest = None,
+        request: Union[document_understanding.ProcessDocumentRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -440,7 +439,7 @@ class DocumentUnderstandingServiceClient(
         r"""Processes a single document.
 
         Args:
-            request (google.cloud.documentai_v1beta2.types.ProcessDocumentRequest):
+            request (Union[google.cloud.documentai_v1beta2.types.ProcessDocumentRequest, dict]):
                 The request object. Request to process one document.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -483,6 +482,19 @@ class DocumentUnderstandingServiceClient(
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
