@@ -55,7 +55,7 @@ class DocumentUnderstandingServiceTransport(abc.ABC):
 
     AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)
 
-    DEFAULT_HOST: str = "us-documentai.googleapis.com"
+    DEFAULT_HOST: str = "documentai.googleapis.com"
 
     def __init__(
         self,
@@ -120,7 +120,7 @@ class DocumentUnderstandingServiceTransport(abc.ABC):
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
 
-        # If the credentials is service account credentials, then always try to use self signed JWT.
+        # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
             always_use_jwt_access
             and isinstance(credentials, service_account.Credentials)
@@ -148,15 +148,7 @@ class DocumentUnderstandingServiceTransport(abc.ABC):
             packaging.version.parse(_GOOGLE_AUTH_VERSION)
             >= packaging.version.parse("1.25.0")
         ):
-            # Documentai uses a regional host (us-documentai.googleapis.com) as the default
-            # so self-signed JWT cannot be used.
-            # Intentionally pass default scopes as user scopes so the auth library
-            # does not use the self-signed JWT flow.
-            # https://github.com/googleapis/python-documentai/issues/174
-            scopes_kwargs = {
-                "scopes": scopes or cls.AUTH_SCOPES,
-                "default_scopes": cls.AUTH_SCOPES,
-            }
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
         else:
             scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
 
@@ -197,6 +189,15 @@ class DocumentUnderstandingServiceTransport(abc.ABC):
             ),
         }
 
+    def close(self):
+        """Closes resources associated with the transport.
+
+       .. warning::
+            Only call this method if the transport is NOT shared
+            with other clients - this may cause errors in other clients!
+        """
+        raise NotImplementedError()
+
     @property
     def operations_client(self) -> operations_v1.OperationsClient:
         """Return the client designed to process long-running operations."""
