@@ -56,7 +56,7 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
     @classmethod
     def create_channel(
         cls,
-        host: str = "us-documentai.googleapis.com",
+        host: str = "documentai.googleapis.com",
         credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
@@ -99,7 +99,7 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
     def __init__(
         self,
         *,
-        host: str = "us-documentai.googleapis.com",
+        host: str = "documentai.googleapis.com",
         credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
@@ -134,16 +134,16 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
-                both in PEM format. It is used to configure mutual TLS channel. It is
+                both in PEM format. It is used to configure a mutual TLS channel. It is
                 ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
@@ -310,5 +310,8 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
             )
         return self._stubs["process_document"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("DocumentUnderstandingServiceGrpcAsyncIOTransport",)
