@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -391,15 +391,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def process_document(
         self,
-        request: document_processor_service.ProcessRequest = None,
+        request: Union[document_processor_service.ProcessRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -409,7 +406,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""Processes a single document.
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.ProcessRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.ProcessRequest, dict]):
                 The request object. Request message for the process
                 document method.
             name (str):
@@ -470,7 +467,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     def batch_process_documents(
         self,
-        request: document_processor_service.BatchProcessRequest = None,
+        request: Union[document_processor_service.BatchProcessRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -481,7 +478,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         written to Cloud Storage as JSON in the [Document] format.
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.BatchProcessRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.BatchProcessRequest, dict]):
                 The request object. Request message for batch process
                 document method.
             name (str):
@@ -553,7 +550,9 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     def fetch_processor_types(
         self,
-        request: document_processor_service.FetchProcessorTypesRequest = None,
+        request: Union[
+            document_processor_service.FetchProcessorTypesRequest, dict
+        ] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -563,7 +562,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""Fetches processor types.
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.FetchProcessorTypesRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.FetchProcessorTypesRequest, dict]):
                 The request object. Request message for fetch processor
                 types.
             parent (str):
@@ -627,7 +626,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     def list_processors(
         self,
-        request: document_processor_service.ListProcessorsRequest = None,
+        request: Union[document_processor_service.ListProcessorsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -637,7 +636,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""Lists all processors which belong to this project.
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.ListProcessorsRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.ListProcessorsRequest, dict]):
                 The request object. Request message for list all
                 processors belongs to a project.
             parent (str):
@@ -708,7 +707,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     def create_processor(
         self,
-        request: document_processor_service.CreateProcessorRequest = None,
+        request: Union[document_processor_service.CreateProcessorRequest, dict] = None,
         *,
         parent: str = None,
         processor: gcd_processor.Processor = None,
@@ -721,7 +720,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         default after its creation.
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.CreateProcessorRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.CreateProcessorRequest, dict]):
                 The request object. Request message for create a
                 processor. Notice this request is sent to a regionalized
                 backend service, and if the processor type is not
@@ -798,7 +797,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     def delete_processor(
         self,
-        request: document_processor_service.DeleteProcessorRequest = None,
+        request: Union[document_processor_service.DeleteProcessorRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -810,7 +809,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         artifacts associated with this processor.
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.DeleteProcessorRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.DeleteProcessorRequest, dict]):
                 The request object. Request message for the delete
                 processor method.
             name (str):
@@ -892,7 +891,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     def enable_processor(
         self,
-        request: document_processor_service.EnableProcessorRequest = None,
+        request: Union[document_processor_service.EnableProcessorRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -901,7 +900,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""Enables a processor
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.EnableProcessorRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.EnableProcessorRequest, dict]):
                 The request object. Request message for the enable
                 processor method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -953,7 +952,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     def disable_processor(
         self,
-        request: document_processor_service.DisableProcessorRequest = None,
+        request: Union[document_processor_service.DisableProcessorRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -962,7 +961,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""Disables a processor
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.DisableProcessorRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.DisableProcessorRequest, dict]):
                 The request object. Request message for the disable
                 processor method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1014,7 +1013,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     def review_document(
         self,
-        request: document_processor_service.ReviewDocumentRequest = None,
+        request: Union[document_processor_service.ReviewDocumentRequest, dict] = None,
         *,
         human_review_config: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1025,7 +1024,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         should be processed by the specified processor.
 
         Args:
-            request (google.cloud.documentai_v1beta3.types.ReviewDocumentRequest):
+            request (Union[google.cloud.documentai_v1beta3.types.ReviewDocumentRequest, dict]):
                 The request object. Request message for review document
                 method. Next Id: 6.
             human_review_config (str):
@@ -1098,6 +1097,19 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
