@@ -32,6 +32,7 @@ from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
 from google.api_core import operation_async  # type: ignore
 from google.api_core import operations_v1
+from google.api_core import path_template
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.documentai_v1beta2.services.document_understanding_service import (
@@ -131,7 +132,7 @@ def test_document_understanding_service_client_from_service_account_info(client_
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "us-documentai.googleapis.com:443"
+        assert client.transport._host == "documentai.googleapis.com:443"
 
 
 @pytest.mark.parametrize(
@@ -177,7 +178,7 @@ def test_document_understanding_service_client_from_service_account_file(client_
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "us-documentai.googleapis.com:443"
+        assert client.transport._host == "documentai.googleapis.com:443"
 
 
 def test_document_understanding_service_client_get_transport_class():
@@ -1024,6 +1025,9 @@ def test_document_understanding_service_base_transport():
         with pytest.raises(NotImplementedError):
             getattr(transport, method)(request=object())
 
+    with pytest.raises(NotImplementedError):
+        transport.close()
+
     # Additionally, the LRO client (a property) should
     # also raise NotImplementedError
     with pytest.raises(NotImplementedError):
@@ -1045,7 +1049,7 @@ def test_document_understanding_service_base_transport_with_credentials_file():
         )
         load_creds.assert_called_once_with(
             "credentials.json",
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=None,
             default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
             quota_project_id="octopus",
         )
@@ -1089,7 +1093,7 @@ def test_document_understanding_service_auth_adc():
         adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         DocumentUnderstandingServiceClient()
         adc.assert_called_once_with(
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=None,
             default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
             quota_project_id=None,
         )
@@ -1175,13 +1179,13 @@ def test_document_understanding_service_transport_create_channel(
         transport_class(quota_project_id="octopus", scopes=["1", "2"])
 
         create_channel.assert_called_with(
-            "us-documentai.googleapis.com:443",
+            "documentai.googleapis.com:443",
             credentials=creds,
             credentials_file=None,
             quota_project_id="octopus",
             default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
             scopes=["1", "2"],
-            default_host="us-documentai.googleapis.com",
+            default_host="documentai.googleapis.com",
             ssl_credentials=None,
             options=[
                 ("grpc.max_send_message_length", -1),
@@ -1241,20 +1245,20 @@ def test_document_understanding_service_host_no_port():
     client = DocumentUnderstandingServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
-            api_endpoint="us-documentai.googleapis.com"
+            api_endpoint="documentai.googleapis.com"
         ),
     )
-    assert client.transport._host == "us-documentai.googleapis.com:443"
+    assert client.transport._host == "documentai.googleapis.com:443"
 
 
 def test_document_understanding_service_host_with_port():
     client = DocumentUnderstandingServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
-            api_endpoint="us-documentai.googleapis.com:8000"
+            api_endpoint="documentai.googleapis.com:8000"
         ),
     )
-    assert client.transport._host == "us-documentai.googleapis.com:8000"
+    assert client.transport._host == "documentai.googleapis.com:8000"
 
 
 def test_document_understanding_service_grpc_transport_channel():
@@ -1526,3 +1530,49 @@ def test_client_withDEFAULT_CLIENT_INFO():
             credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
+
+
+@pytest.mark.asyncio
+async def test_transport_close_async():
+    client = DocumentUnderstandingServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+    )
+    with mock.patch.object(
+        type(getattr(client.transport, "grpc_channel")), "close"
+    ) as close:
+        async with client:
+            close.assert_not_called()
+        close.assert_called_once()
+
+
+def test_transport_close():
+    transports = {
+        "grpc": "_grpc_channel",
+    }
+
+    for transport, close_name in transports.items():
+        client = DocumentUnderstandingServiceClient(
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport
+        )
+        with mock.patch.object(
+            type(getattr(client.transport, close_name)), "close"
+        ) as close:
+            with client:
+                close.assert_not_called()
+            close.assert_called_once()
+
+
+def test_client_ctx():
+    transports = [
+        "grpc",
+    ]
+    for transport in transports:
+        client = DocumentUnderstandingServiceClient(
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport
+        )
+        # Test client calls underlying transport.
+        with mock.patch.object(type(client.transport), "close") as close:
+            close.assert_not_called()
+            with client:
+                pass
+            close.assert_called()
